# 德语零基础教程

无论是计算机编程语言，还是自然语言，都有所谓的「Grammar」，在计算机领域里译为「文法」，在语言学里译为「语法」。
与编程语言所具有的严格的二、三型文法规则不同，自然语言是上下文有关的一型文法，其语法通常变化非常大，至少目前来说，
没有一个形式化、统一的方法能够描述我们的自然语言，总会出现这样那样的例外。特殊情况下，甚至无法为一个合理的句型加以合理的解释。
好在德语要比英语严谨的多，比如总所周知的，德语没有音标，可以根据一个单词的拼写直接读出这个单词，而且大部分情况下根据语境的判断，反过来也成立。
所以如果除开需要「死记硬背」毫无逻辑的内容外，德语要比英语易学得多。

一门语言在人类社会中不断的发展和进化，会从听、说、读、写四个方面来契合将这门语言作为母语使用者的使用习惯，
从而发展出来了所谓的「词性」「变位」「元音变音」等等这些无法规则描述的「冗余」信息。但试想我们的中文又何尝不是如此，
恐怕没几个人能解释得了为什么中文在描述不同对象的数量时，存在不同的量词；比如「一双鞋」、「两个人」、「三头牛」。
所以，自然语言更重在频繁的去使用这门语言（因此一门语言的最惧怕的也就是没有了使用者），而不是刻板的通晓语法。
只有「习惯」了它的存在即合理的方式，才能更加熟练的使用它（das Deutsch）。

话虽如此，但作为非母语的学习者来说，不可否认的是：语言中的基本成分、基本结构、基本概念等等，是理解一门新语言的重要基础，
因为一定程度的语法知识能将这门新的语言与自己已经熟悉的那些语言做对比，进而加深理解，快速学习。
这与当我们已经熟悉一门程序语言后，再去快速浏览其他语言时，总会出现「似曾相识」的感觉是完全一样的。

本教程以一个计算机程序员的角度，混合中文、英文的思维，假定读者在精通中文、熟悉英语的前提下，
尝试用对比的思维方式从零基础开始介绍德语，从中文为母语的角度来视图审视并解释英语和德语在表达上的优势，
进而学到充分的德语知识。尽管本书涉及内容很多，但这不是一本完整的语法参考手册，本书的合理阅读时间为一个月。
阅读完本教程，你能够：

1. 理解德语到底是一门怎样的语言，为什么很多人认为德语很难；
2. 学到阅读、理解德语最重要的、必备的语法知识（A1 ~ B2）；
3. 正确的构造并写出没有错误的德语句子；
4. 待补充

## 目录

### 第零部分 基础

- [0.1 基础概念](grammar/basis.md)
- [0.2 发音](grammar/pronounciation.md)
- [0.3 基本词汇](grammar/base.md)
- [0.4 构词](grammar/formation.md)
- [0.5 词序](grammar/order.md)

### 第一部分 词法

- [1.1 冠词 Articles](grammar/articles.md)
- [1.2 名词 Nouns](grammar/nouns.md)
- [1.3 代词 Pronouns](grammar/pronouns.md)
- [1.4 介词 Prepositions](grammar/prepositions.md)
- [1.5 动词 Verbs](grammar/verbs.md)
- [1.6 形容词 Adjective](grammar/adjectives.md)
- [1.7 副词 Adverbs](grammar/advers.md)

### 第二部分 句法

- [2.1 现在时 Present Tense](grammar/present.md)
- [2.2 过去时 Past Tense](grammar/past.md)
- [2.3 「将来」时 Future Tense](grammar/future.md)
- [2.4 虚拟语态 Subjunctive](grammar/subjunctive.md)
- [2.5 被动语态 Passive](grammar/passive.md)
- [2.6 从句 Linker](grammar/linkers.md)

### 第三部分 清单

- [3.1「与格」动词](wordlist/dative-verbs.md)
- [3.2 A1 词汇清单]()
- [3.3 A2 词汇清单]()
- [3.4 B1 词汇清单]()
- [3.5 B2 词汇清单]()

- [结束语](end.md)

## TODO

- [ ] 解释语言学基本知识
- [ ] 完成全部正文内容
- [ ] 在适当的部分插入适当的习题
- [ ] 补充词汇表

## 纠错

本教程系基于笔者从零开始使用英语学习德语时课堂（A1）笔记整理而成。
如果你发现了教程中出现了错误，希望能尽快通过 issue 指出，以免误导他人。笔者对此深表感谢。

## 许可

<a rel="license" href="http://creativecommons.org/licenses/by-nc-nd/4.0/"><img alt="知识共享许可协议" style="border-width:0" src="https://i.creativecommons.org/l/by-nc-nd/4.0/88x31.png" /></a><br /><span xmlns:dct="http://purl.org/dc/terms/" href="http://purl.org/dc/dcmitype/Text" property="dct:title" rel="dct:type">德语零基础教程</span> 由 <a xmlns:cc="http://creativecommons.org/ns#" href="https://changkun.us/" property="cc:attributionName" rel="cc:attributionURL">欧长坤</a> 采用 <a rel="license" href="http://creativecommons.org/licenses/by-nc-nd/4.0/">知识共享 署名-非商业性使用-禁止演绎 4.0 国际 许可协议</a>进行许可。